Environment

Struct Environment 

pub struct Environment { /* private fields */ }
A wrapper around the stored values obtained during evaluation.

Implementations

Source

impl Environment

pub fn new() -> Environment

Construct a new blank environment.

pub fn new_enclosed_environment(outer: &Env) -> Environment

Constructs a new enclosed environment within the outer environment.

pub fn get(&self, name: &str) -> Option<Rc<Object>>

Retrieves the value associated with a key, if it exists.

pub fn set(&mut self, name: &str, val: Rc<Object>)

Sets the value for a given key. If the key is already present in the environment, its value is updated.